@@ -1,5 +1,7 @@
 import click
 import os
+import sys
+import subprocess
 
 __location__ = os.path.realpath(
     os.path.join(os.getcwd(), os.path.dirname(__file__)))
@@ -54,6 +56,10 @@ def cli():
 
     ds-framework-cli g predictable my-new-predictable
 
+    run server
+
+    ds-framework-cli run-server
+
     """
 # @click.option("--type", prompt="type", help="type of component")
 # @click.option("--project_name", prompt="project_name", help="project_name")
@@ -72,6 +78,14 @@ def generate(type, project_name):
         return
     f(project_name)
 
+@cli.command()
+def run_server():
+    currentPipelineFolder = os.path.abspath(os.getcwd())
+    currentParentFolder = os.path.join(currentPipelineFolder,"..")
+    os.environ["PYTHONPATH"] = currentParentFolder
+    folder = currentPipelineFolder + '/server/server.py'
+    subprocess.call('python ' + folder, shell=True)
+
 ALIASES = {
     "g": generate
 }
@@ -101,8 +115,8 @@ def create_folders(projectName):
 
     create_main_folders(projectName, 'pipeline', 'main')
     create_main_folders(projectName, 'artifacts', 'pipeline')
-    # create_main_folders(projectName, 'models', 'artifacts')
-    # create_main_folders(projectName, 'vocabs', 'artifacts')
+    create_main_folders(projectName, 'models', 'artifacts')
+    create_main_folders(projectName, 'vocabs', 'artifacts')
     # create_main_folders(projectName, 'other', 'artifacts')
     create_main_folders(projectName, 'preprocessor', 'pipeline')
     create_main_folders(projectName, 'predictables', 'pipeline')
@@ -128,7 +142,8 @@ def create_project(projectName):
     create_pipeline_file(projectName, directories['main'], 'test_pipeline', False)
     # create_testet_file(projectName, directories['tester'], 'tester')
     # create_testet_file(projectName, directories['tester'], 'reporter')
-    # create_testet_file(projectName, directories['server'], 'server')
+    create_testet_file(projectName, directories['server'], 'server', False)
+    create_testet_file(projectName, directories['server'], 'test_server_post', False)
     # create_testet_file(projectName, directories['trainer'], 'trainer')
     # create_pipeline_file(projectName, 'labelizer')
     # create_pipeline_file(projectName, 'pipeline')
@@ -206,7 +221,7 @@ def create_exist_pipeline_file(type, fileName):
 def create_predictable_file(fileName):
     pass
 
-def create_testet_file(projectName, folder, pipelineType):
+def create_testet_file(projectName, folder, pipelineType, createInitFile=True):
     with open(os.path.join(__location__, 'cli/tester/' + pipelineType + '_template.py'), 'r') as file:
         data = file.read()
         projectNameNoUnderscore = ''.join(elem.capitalize() for elem in projectName.split('_'))
@@ -217,8 +232,11 @@ def create_testet_file(projectName, folder, pipelineType):
         data = data.replace('generatedClass',className)
         data = data.replace('generatedProjectName',projectNameNoUnderscore)
         currentDir = folder.replace('/', '.')
+        currentBaseDir = directories['main'].replace('/', '.')
+        currentPipelineDir = directories['pipeline'].replace('/', '.')
         data = data.replace('generatedDirectory', currentDir)
-        data = data.replace('generatedMainDirectory', directories['main'].replace('/', '.'))
+        data = data.replace('generatedBaseDir', currentBaseDir)
+        data = data.replace('generatedPipelineDir', currentPipelineDir)
         new_file = folder + "/" + pipelineType + ".py"
         new_init_file = folder + "/__init__.py"
         new_init_export = "from " + currentDir + '.' + pipelineType + " import " + className
@@ -226,7 +244,8 @@ def create_testet_file(projectName, folder, pipelineType):
             f = open(new_file, "w")
             f.write(data)
             f.close()
-        create_tester_init_file(new_init_file, new_init_export)
+        if createInitFile:
+            create_tester_init_file(new_init_file, new_init_export)
 
 def create_pipeline_init_file(init_path, init_export):
     if not os.path.exists(init_path):
