@@ -17,6 +17,6 @@ class generatedClass(ZIDS_Postprocessor):
         pass
 
     def normalize_output(self, predictables: List[ZIDS_Predictable]) -> Any:
-        if predictables:
-            pass
-            # return generatedProjectNameOutputs(predictables)
+        raise NotImplementedError
+        # if predictables:
+        #     # return generatedProjectNameOutputs(predictables)
