@@ -14,7 +14,7 @@ class generatedClass(ZIDS_Preprocessor):
     def __init__(self, artifacts: generatedProjectNameSharedArtifacts = None):
         super().__init__(artifacts)
 
-    def normalize_input(self, **kwargs: Any) -> ZIDS_Object:
+    def normalize_input(self, **kwargs: Any) -> generatedProjectNameInputs:
         return generatedProjectNameInputs(**kwargs)
 
     def config(self):
