@@ -8,10 +8,9 @@ class generatedClass(ZIDS_SharedArtifacts):
 
     def __init__(self) -> None:
         super().__init__()
-        self.load_config()
 
-    def load_config(self):
-        f = open('config.json', )
-        data = json.load(f)
-        for item in data:
-            setattr(self, item, data[item])
+    def load_vocabs(self):
+        pass
+
+    def load_artifacts(self):
+        pass
